@@ -1,4 +1,4 @@
-﻿define(['appSettings'], function (appSettings) {
+﻿define(['appSettings', 'appStorage', 'libraryBrowser', 'jQuery'], function (appSettings, appStorage, LibraryBrowser, $) {
 
     var showOverlayTimeout;
 
@@ -28,10 +28,15 @@
             return;
         }
 
+        if (!elem.animate) {
+            elem.classList.add('hide');
+            return;
+        }
+
         requestAnimationFrame(function () {
             var keyframes = [
-              { height: '100%', offset: 0 },
-              { height: '0', offset: 1 }];
+              { transform: 'translateY(0)', offset: 0 },
+              { transform: 'translateY(100%)', offset: 1 }];
             var timing = { duration: 300, iterations: 1, fill: 'forwards', easing: 'ease-out' };
 
             elem.animate(keyframes, timing).onfinish = function () {
@@ -48,12 +53,15 @@
 
         elem.classList.remove('hide');
 
+        if (!elem.animate) {
+            return;
+        }
+
         requestAnimationFrame(function () {
-            elem.style.display = 'block';
 
             var keyframes = [
-              { height: '0', offset: 0 },
-              { height: '100%', offset: 1 }];
+              { transform: 'translateY(100%)', offset: 0 },
+              { transform: 'translateY(0)', offset: 1 }];
             var timing = { duration: 300, iterations: 1, fill: 'forwards', easing: 'ease-out' };
             elem.animate(keyframes, timing);
         });
@@ -196,7 +204,7 @@
 
     function onMoreButtonClick() {
 
-        var card = $(this).parents('.card')[0];
+        var card = parentWithClass(this, 'card');
 
         showContextMenu(card, {
             showPlayOptions: false
@@ -478,10 +486,16 @@
                                 break;
                             case 'download':
                                 {
-                                    var downloadHref = ApiClient.getUrl("Items/" + itemId + "/Download", {
-                                        api_key: ApiClient.accessToken()
+                                    require(['fileDownloader'], function (fileDownloader) {
+                                        var downloadHref = ApiClient.getUrl("Items/" + itemId + "/Download", {
+                                            api_key: ApiClient.accessToken()
+                                        });
+
+                                        fileDownloader([{
+                                            url: downloadHref,
+                                            itemId: itemId
+                                        }]);
                                     });
-                                    window.location.href = downloadHref;
 
                                     break;
                                 }
@@ -522,7 +536,7 @@
                                 MediaController.play(itemId);
                                 break;
                             case 'playallfromhere':
-                                playAllFromHere(index, $(card).parents('.itemsContainer'), 'play');
+                                playAllFromHere(index, parentWithClass(card, 'itemsContainer'), 'play');
                                 break;
                             case 'queue':
                                 MediaController.queue(itemId);
@@ -539,7 +553,7 @@
                                 });
                                 break;
                             case 'queueallfromhere':
-                                playAllFromHere(index, $(card).parents('.itemsContainer'), 'queue');
+                                playAllFromHere(index, parentWithClass(card, 'itemsContainer'), 'queue');
                                 break;
                             case 'sync':
                                 require(['syncDialog'], function (syncDialog) {
@@ -715,7 +729,7 @@
         return elem;
     }
 
-    $.fn.createCardMenus = function (options) {
+    LibraryBrowser.createCardMenus = function (curr, options) {
 
         var preventHover = false;
 
@@ -802,32 +816,37 @@
             preventHover = true;
         }
 
+        curr.removeEventListener('click', onCardClick);
+        curr.addEventListener('click', onCardClick);
+
+        if (AppInfo.isTouchPreferred) {
+
+            curr.removeEventListener('contextmenu', disableEvent);
+            curr.addEventListener('contextmenu', disableEvent);
+        }
+        else {
+            curr.removeEventListener('contextmenu', onContextMenu);
+            curr.addEventListener('contextmenu', onContextMenu);
+
+            curr.removeEventListener('mouseenter', onHoverIn);
+            curr.addEventListener('mouseenter', onHoverIn, true);
+
+            curr.removeEventListener('mouseleave', onHoverOut);
+            curr.addEventListener('mouseleave', onHoverOut, true);
+
+            curr.removeEventListener("touchstart", preventTouchHover);
+            curr.addEventListener("touchstart", preventTouchHover);
+        }
+
+        initTapHoldMenus(curr);
+    };
+
+    $.fn.createCardMenus = function (options) {
+
         for (var i = 0, length = this.length; i < length; i++) {
 
             var curr = this[i];
-            curr.removeEventListener('click', onCardClick);
-            curr.addEventListener('click', onCardClick);
-
-            if (AppInfo.isTouchPreferred) {
-
-                curr.removeEventListener('contextmenu', disableEvent);
-                curr.addEventListener('contextmenu', disableEvent);
-            }
-            else {
-                curr.removeEventListener('contextmenu', onContextMenu);
-                curr.addEventListener('contextmenu', onContextMenu);
-
-                curr.removeEventListener('mouseenter', onHoverIn);
-                curr.addEventListener('mouseenter', onHoverIn, true);
-
-                curr.removeEventListener('mouseleave', onHoverOut);
-                curr.addEventListener('mouseleave', onHoverOut, true);
-
-                curr.removeEventListener("touchstart", preventTouchHover);
-                curr.addEventListener("touchstart", preventTouchHover);
-            }
-
-            initTapHoldMenus(curr);
+            LibraryBrowser.createCardMenus(curr, options);
         }
 
         return this;
@@ -879,7 +898,7 @@
 
     function showTapHoldHelp(element) {
 
-        var page = $(element).parents('.page')[0];
+        var page = parentWithClass(element, 'page');
 
         if (!page) {
             return;
@@ -1138,6 +1157,16 @@
                 ironIcon: 'call-merge'
             });
 
+            items.push({
+                name: Globalize.translate('MarkPlayed'),
+                id: 'markplayed'
+            });
+
+            items.push({
+                name: Globalize.translate('MarkUnplayed'),
+                id: 'markunplayed'
+            });
+
             items.push({
                 name: Globalize.translate('ButtonRefresh'),
                 id: 'refresh',
@@ -1177,12 +1206,24 @@
                                 break;
                             case 'delete':
                                 LibraryBrowser.deleteItems(items).then(function () {
-                                    Dashboard.navigate('index.html');
+                                    Dashboard.navigate('home.html');
                                 });
                                 hideSelections();
                                 break;
                             case 'groupvideos':
-                                combineVersions($($.mobile.activePage)[0], items);
+                                combineVersions($.mobile.activePage, items);
+                                break;
+                            case 'markplayed':
+                                items.forEach(function(itemId) {
+                                    ApiClient.markPlayed(Dashboard.getCurrentUserId(), itemId);
+                                });
+                                hideSelections();
+                                break;
+                            case 'markunplayed':
+                                items.forEach(function (itemId) {
+                                    ApiClient.markUnplayed(Dashboard.getCurrentUserId(), itemId);
+                                });
+                                hideSelections();
                                 break;
                             case 'refresh':
                                 items.map(function (itemId) {
@@ -1286,7 +1327,7 @@
 
             index = elemWithAttributes.getAttribute('data-index');
 
-            itemsContainer = $(elem).parents('.itemsContainer');
+            itemsContainer = parentWithClass(elem, 'itemsContainer');
 
             playAllFromHere(index, itemsContainer, 'play');
         }
@@ -1372,7 +1413,7 @@
 
         var itemsContainers = page.querySelectorAll('.itemsContainer:not(.noautoinit)');
         for (var i = 0, length = itemsContainers.length; i < length; i++) {
-            $(itemsContainers[i]).createCardMenus();
+            LibraryBrowser.createCardMenus(itemsContainers[i]);
         }
 
         $('.categorySyncButton', page).on('click', function () {
@@ -1453,7 +1494,7 @@
             if (mediaType == 'Video') {
                 this.setAttribute('data-positionticks', (userData.PlaybackPositionTicks || 0));
 
-                if ($(this).hasClass('card')) {
+                if (this.classList.contains('card')) {
                     renderUserDataChanges(this, userData);
                 }
             }
