@@ -196,7 +196,34 @@ define(['appSettings', 'userSettings', 'appStorage'], function (appSettings, use
 
             return new Promise(function (resolve, reject) {
 
-                require(['browserdeviceprofile', 'qualityoptions'], function (profile, qualityoptions) {
+                require(['browserdeviceprofile', 'qualityoptions'], function (profileBuilder, qualityoptions) {
+
+                    var supportsCustomSeeking = false;
+                    if (!browserInfo.mobile) {
+                        supportsCustomSeeking = true;
+                    } else if (AppInfo.isNativeApp && browserInfo.safari) {
+                        if (navigator.userAgent.toLowerCase().indexOf('ipad') == -1) {
+                            // Need to disable it in order to support picture in picture
+                            supportsCustomSeeking = true;
+                        }
+                    } else if (AppInfo.isNativeApp) {
+                        supportsCustomSeeking = true;
+                    }
+
+                    var profile = profileBuilder({
+                        supportsCustomSeeking: supportsCustomSeeking
+                    });
+
+                    if (!(AppInfo.isNativeApp && browserInfo.android)) {
+                        profile.SubtitleProfiles.push({
+                            Format: 'ass',
+                            Method: 'External'
+                        });
+                        profile.SubtitleProfiles.push({
+                            Format: 'ssa',
+                            Method: 'External'
+                        });
+                    }
 
                     var bitrateSetting = appSettings.maxStreamingBitrate();
 
@@ -235,10 +262,12 @@ define(['appSettings', 'userSettings', 'appStorage'], function (appSettings, use
         function canPlayerSeek() {
 
             var mediaRenderer = self.currentMediaRenderer;
-            var currentSrc = self.getCurrentSrc(mediaRenderer);
+            var currentSrc = (self.getCurrentSrc(mediaRenderer) || '').toLowerCase();
 
-            if ((currentSrc || '').indexOf('.m3u8') != -1) {
-                return true;
+            if (currentSrc.indexOf('.m3u8') != -1) {
+                if (currentSrc.indexOf('forcelivestream=true') == -1) {
+                    return true;
+                }
             } else {
                 var duration = mediaRenderer.duration();
                 return duration && !isNaN(duration) && duration != Number.POSITIVE_INFINITY && duration != Number.NEGATIVE_INFINITY;
@@ -428,7 +457,8 @@ define(['appSettings', 'userSettings', 'appStorage'], function (appSettings, use
                     url: textStreamUrl,
                     language: (textStream.Language || 'und'),
                     isDefault: textStream.Index == mediaSource.DefaultSubtitleStreamIndex,
-                    index: textStream.Index
+                    index: textStream.Index,
+                    format: textStream.Codec
                 });
             }
 
@@ -707,7 +737,11 @@ define(['appSettings', 'userSettings', 'appStorage'], function (appSettings, use
 
                             if (mediaSource.TranscodingSubProtocol == 'hls') {
 
-                                mediaUrl += seekParam;
+                                if (mediaUrl.toLowerCase().indexOf('forcelivestream=true') != -1) {
+                                    startPositionInSeekParam = 0;
+                                    startTimeTicksOffset = startPosition || 0;
+                                }
+
                                 contentType = 'application/x-mpegURL';
 
                             } else {
@@ -1578,9 +1612,9 @@ define(['appSettings', 'userSettings', 'appStorage'], function (appSettings, use
 
         window.addEventListener("beforeunload", onAppClose);
 
-        if (browserInfo.safari) {
-            document.addEventListener("pause", onAppClose);
-        }
+        //if (browserInfo.safari) {
+        //    document.addEventListener("pause", onAppClose);
+        //}
 
         function sendProgressUpdate() {
 
