@@ -1,4 +1,4 @@
-﻿define(['libraryBrowser'], function (libraryBrowser) {
+﻿define(['libraryBrowser', 'scrollStyles'], function (libraryBrowser) {
 
     var searchHintTimeout;
 
@@ -44,7 +44,7 @@
         }
         else if (hint.Type == "Series") {
 
-            return [Globalize.translate('LabelSeries')];
+            return [Globalize.translate('Series')];
         }
         else if (hint.Type == "BoxSet") {
 
@@ -109,7 +109,7 @@
         ApiClient.getSearchHints({
 
             userId: Dashboard.getCurrentUserId(),
-            searchTerm: searchTerm,
+            searchTerm: (searchTerm || '').trim(),
             limit: 30
 
         }).then(function (result) {
@@ -158,6 +158,8 @@
 
             document.body.appendChild(div);
             libraryBrowser.createCardMenus(div);
+
+            elem = div;
         }
 
         return elem;
@@ -203,7 +205,10 @@
           { opacity: '0', offset: 0 },
           { opacity: '1', offset: 1 }];
         var timing = { duration: 200, iterations: iterations, fill: 'both' };
-        elem.animate(keyframes, timing);
+
+        if (elem.animate) {
+            elem.animate(keyframes, timing);
+        }
     }
 
     function fadeOut(elem, iterations) {
@@ -211,9 +216,16 @@
           { opacity: '1', offset: 0 },
           { opacity: '0', offset: 1 }];
         var timing = { duration: 600, iterations: iterations, fill: 'both' };
-        elem.animate(keyframes, timing).onfinish = function () {
+
+        var onfinish = function () {
             elem.parentNode.removeChild(elem);
         };
+
+        if (elem.animate) {
+            elem.animate(keyframes, timing).onfinish = onfinish;
+        } else {
+            onfinish();
+        }
     }
 
     function bindSearchEvents() {
