@@ -961,7 +961,14 @@
             };
 
             self._enhance();
-            self.element.enhanceWithin();
+
+            var requireValues = pageElem.getAttribute('data-require');
+            if (requireValues && requireValues.indexOf('jqm') != -1) {
+                self.element.enhanceWithin();
+            }
+            else if ((pageElem.getAttribute('data-url') || '').toLowerCase().indexOf('/configurationpage?') != -1) {
+                self.element.enhanceWithin();
+            }
 
             pageElem.dispatchEvent(new CustomEvent("pageinit", {
                 bubbles: true
@@ -1196,12 +1203,7 @@
 
                     if (contentElem.classList.contains('type-interior')) {
                         dependencies = dependencies || [];
-                        dependencies.push('jqmpopup');
-                        dependencies.push('jqmlistview');
-                        dependencies.push('jqmcollapsible');
-                        dependencies.push('jqmcontrolgroup');
-                        dependencies.push('jqmcheckbox');
-                        dependencies.push('scripts/notifications');
+                        addLegacyDependencies(dependencies, absUrl);
                     }
 
                     require(dependencies, function () {
